@@ -538,8 +538,20 @@ def load_orig(ssh1,dir1name, ssh2,dir2name):
 
 	ignores1 = get_ignores(ignorefile1, ssh1,dir1name)
 	ignores2 = get_ignores(ignorefile2, ssh2,dir2name)
-	ignores_global = readlines(get_config_path("ignore"))
-	ignores = parse_gitignore(ignores1 | ignores2 | set(ignores_global))
+	ignores_global = set(readlines(get_config_path("ignore")))
+
+	try:
+		ignores_global_remote = ssh.check_output(
+			"cat", ".config/synecure/ignore",
+			stderr=subprocess.DEVNULL
+		).run().decode("utf8").split("\n")
+		ignores_global_remote = set(ignores_global_remote)
+	except Exception as exc:
+		ignores_global_remote = set()
+
+	all_ignores = ignores1 | ignores2 | ignores_global | ignores_global_remote
+	all_ignores.discard("")
+	ignores = parse_gitignore(all_ignores)
 
 	common_snaps = snaps1.intersection(snaps2)
 	orig = collections.OrderedDict()
@@ -888,6 +900,8 @@ def usage():
 	usage+= "	-d		Make the dirs if they do not exist\n"
 	usage+= "	-n		Dry run: report changes without applying them\n"
 	usage+= "	-y		Apply the changes when no conflict\n"
+	usage+= "	-1		Keep local version of changes on conflict\n"
+	usage+= "	-2		Keep remote version of changes on conflict\n"
 	usage+= "	-p PORT		Port for SSH\n"
 	usage+= "	-o SSHARGS	Custom options for SSH\n"
 	printerr(usage)
@@ -896,7 +910,7 @@ def usage():
 
 #### process commandline args
 try:
-	opts, args = getopt.gnu_getopt(sys.argv[1:], "vcibdnyp:o:")
+	opts, args = getopt.gnu_getopt(sys.argv[1:], "vcibdny12p:o:")
 except getopt.GetoptError as err:
 	printerr(err)
 	usage()
@@ -905,6 +919,7 @@ except getopt.GetoptError as err:
 verbose = check = ignoreperms = batch = mkdirp = dry_run = yes = False
 sshport = None
 sshargs = ""
+tokeep = None
 for o, a in opts:
 	if o == "-v":
 		verbose = True
@@ -924,6 +939,10 @@ for o, a in opts:
 		mkdirp = True
 	elif o == "-n":
 		dry_run = True
+	elif o == "-1":
+		tokeep = "1a"
+	elif o == "-2":
+		tokeep = "2a"
 	else:
 		assert False, "unhandled option"
 
@@ -1031,7 +1050,6 @@ copy12 = []
 copy21 = []
 sync12 = []
 sync21 = []
-tokeep = None
 # process all original paths (from snapshot)
 for path, fo in origlist.items():
 	# f1==None f2==None				deleted both sides
