@@ -5,7 +5,15 @@ import subprocess
 import shlex
 from coleo import Option, default, run_cli
 
-from .utils import get_config, get_config_path, write_config, readlines, writelines, quote
+from .utils import (
+    get_config,
+    get_config_path,
+    edit_config,
+    write_config,
+    readlines,
+    writelines,
+    quote,
+)
 
 
 def q(message=None):
@@ -16,15 +24,11 @@ def _cfg_from_url(name, port=22):
     if "@" in name:
         if ":" in name:
             name, port = name.split(":")
-        else:
-            port = 22
         return {
             "type": "ssh",
             "url": name,
             "port": port,
-            "paths": {
-                os.getenv("HOME"): ""
-            }
+            "paths": {os.getenv("HOME"): ""},
         }
     else:
         return None
@@ -112,6 +116,21 @@ def main():
     # [alias: -i]
     interactive: Option & bool = default(False)
 
+    # Resolve a conflict with "local" or "remote" copy (default: "prompt")
+    resolve: Option = default("prompt")
+    if resolve not in ("local", "remote", "prompt"):
+        sys.exit("ERROR: resolve must be 'local', 'remote' or 'prompt'")
+
+    # Resolve a conflict with local copy
+    # [option: -1]
+    # [false-options: -2]
+    # [false-options-doc: Resolve a conflict with remote copy]
+    resolve_local: Option & bool = default(None)
+    if resolve_local is True:
+        resolve = "local"
+    if resolve_local is False:
+        resolve = "remote"
+
     remotes = get_config("remotes.json")
     directories = get_config("directories.json")
 
@@ -127,10 +146,14 @@ def main():
     for filename in files:
         filename = os.path.realpath(os.path.expanduser(filename))
         commands += plan_sync(
-            filename, remote, remotes, directories,
+            filename,
+            remote,
+            remotes,
+            directories,
             dry=dry_run,
             verbose=verbose,
-            interactive=interactive
+            interactive=interactive,
+            resolve=resolve,
         )
 
     for command in commands:
@@ -158,16 +181,29 @@ def _check_dir(url, path, port):
         return os.path.isdir(path)
 
 
-def plan_sync(path, remote_name, remotes, directories,
-              dry=False, verbose=False, interactive=False):
+def plan_sync(
+    path,
+    remote_name,
+    remotes,
+    directories,
+    dry=False,
+    verbose=False,
+    interactive=False,
+    resolve="prompt",
+):
     if remote_name is None:
         if path not in directories:
             q("Please specify a destination")
         regdest = directories[path]
         assert regdest is not None
-        return plan_sync(path, regdest, remotes, directories,
+        return plan_sync(
+            path,
+            regdest,
+            remotes,
+            directories,
             dry=dry,
-            interactive=interactive
+            interactive=interactive,
+            resolve=resolve,
         )
 
     directories[path] = remote_name
@@ -175,11 +211,13 @@ def plan_sync(path, remote_name, remotes, directories,
     remote = _check_remote(remotes, remote_name)
     for pfx, repl in _sort_paths(remote):
         if path.startswith(pfx):
-            destpath = os.path.join(repl, path[len(pfx) + 1:])
+            destpath = os.path.join(repl, path[len(pfx) + 1 :])
             break
     else:
-        q(f"There is no rule to remap path '{path}' on '{remote_name}'"
-          f"\nTry: 'sy-remote path {remote_name} <SRC_PREFIX> <DEST_PREFIX>'")
+        q(
+            f"There is no rule to remap path '{path}' on '{remote_name}'"
+            f"\nTry: 'sy-remote path {remote_name} <SRC_PREFIX> <DEST_PREFIX>'"
+        )
 
     print(f"# SYNC LOCAL      {path}")
     if remote["type"] == "ssh":
@@ -209,6 +247,11 @@ def plan_sync(path, remote_name, remotes, directories,
         else:
             cmdopts.append("-y")
 
+        if resolve == "local":
+            cmdopts.append("-1")
+        elif resolve == "remote":
+            cmdopts.append("-2")
+
         if remote["type"] == "ssh":
             cmdopts.append(f"-p {remote['port']}")
 
@@ -225,9 +268,11 @@ def plan_sync(path, remote_name, remotes, directories,
             common.append("-v")
         if remote["type"] == "ssh":
             common += [
-                "-e", f"ssh -p {remote['port']}",
+                "-e",
+                f"ssh -p {remote['port']}",
                 # This is a dirty trick to create the directory on the remote
-                "--rsync-path", f"mkdir -p {destdir}; rsync",
+                "--rsync-path",
+                f"mkdir -p {destdir}; rsync",
             ]
         elif remote["type"] == "local":
             commands.append(["mkdir", "-p", destdir])
@@ -246,6 +291,7 @@ def plan_sync(path, remote_name, remotes, directories,
 
 
 def config_add():
+    """Add a new remote or edit an existing one."""
     # Name of the remote
     # [positional]
     name: Option
@@ -266,14 +312,13 @@ def config_add():
             "type": "local",
             "url": "localhost",
             "port": None,
-            "paths": {
-                os.getenv("HOME"): os.path.realpath(os.path.expanduser(url))
-            }
+            "paths": {os.getenv("HOME"): os.path.realpath(os.path.expanduser(url))},
         }
     write_config("remotes.json", cfg)
 
 
 def config_view():
+    """View configuration for a remote."""
     # Name of the remote
     # [positional: ?]
     name: Option
@@ -286,9 +331,10 @@ def config_view():
 
 
 def config_list():
+    """List existing remotes and paths."""
     cfg = get_config("remotes.json")
     for name, defn in cfg.items():
-        if defn['port'] in (None, 22):
+        if defn["port"] in (None, 22):
             port = ""
         else:
             port = f":{defn['port']}"
@@ -297,7 +343,13 @@ def config_list():
             print(f"    {local_path:30} -> :{remote_path}")
 
 
+def config_edit():
+    """Edit the configuration file directly."""
+    edit_config("remotes.json")
+
+
 def config_path():
+    """Edit path mappings for a remote."""
     # Name of the remote
     # [positional]
     name: Option
@@ -342,6 +394,7 @@ def config_path():
 
 
 def config_remove():
+    """Remove a remote."""
     # Name of the remote
     # [positional]
     name: Option
@@ -353,37 +406,45 @@ def config_remove():
 
 
 def config_ignore():
+    """Add/remove global ignore patterns."""
     # Patterns to ignore
     # [positional: *]
     patterns: Option = default([])
 
-    ign = get_config_path("ignore")
-    lines = readlines(ign)
+    # List the ignores
+    # [alias: -l]
+    list: Option & bool = default(False)
 
-    for line in lines:
-        print(f" {line}")
-    for pattern in patterns:
-        if pattern not in lines:
-            print(f"+{pattern}")
-            lines.append(pattern)
-
-    writelines(ign, lines)
-
-
-def config_unignore():
-    # Patterns to ignore
-    # [positional: *]
-    patterns: Option = default([])
+    # Remove the ignores
+    # [alias: -r]
+    # [nargs: *]
+    remove: Option = default([])
 
     ign = get_config_path("ignore")
-    lines = readlines(ign)
 
+    if list:
+        print(open(ign).read(), end="")
+        sys.exit(0)
+
+    if not patterns:
+        edit_config("ignore")
+        sys.exit(0)
+
+    lines = readlines(ign)
     new_lines = []
+
     for line in lines:
-        if line in patterns:
+        if line in remove:
             print(f"-{line}")
         else:
             print(f" {line}")
             new_lines.append(line)
 
-    writelines(ign, new_lines)
+    no_add = {*lines, *remove}
+
+    for pattern in patterns:
+        if pattern not in no_add:
+            print(f"+{pattern}")
+            lines.append(pattern)
+
+    writelines(ign, lines)
